@@ -360,7 +360,7 @@ class TibberHome:
     def current_price_data(self) -> Optional[tuple[float, str, dt.datetime]]:
         """Get current price."""
         price_time = (
-            dt.datetime.utcnow()
+            dt.datetime.now()
             .replace(minute=0, second=0, microsecond=0)
             .astimezone(self._tibber_control.time_zone)
         )
@@ -524,9 +524,10 @@ class TibberHome:
         attr["off_peak_2"] = round(off_peak_2 / num2, 3) if num2 > 0 else 0
         if (
             "glitre"
-            in self.info["viewer"]["home"]["meteringPointData"]
-            .get("gridCompany", "")
-            .lower()
+            in (
+                self.info["viewer"]["home"]["meteringPointData"].get("gridCompany")
+                or ""
+            ).lower()
         ):
             if now.month < 7:
                 grid_price = 47.39 / 100
